summaryrefslogtreecommitdiffstats
path: root/tools/isolate_driver.py
diff options
context:
space:
mode:
authormaruel@chromium.org <maruel@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-05-06 03:53:47 +0000
committermaruel@chromium.org <maruel@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-05-06 03:53:47 +0000
commit3559fc424d5cbd299bdc02973b8e6b3c87a406ab (patch)
treeca4dedb387ff57278e6dcb9e07818089432c78da /tools/isolate_driver.py
parent546c4626f1c323a9b28699f2a398a0a42c1bc4bf (diff)
downloadchromium_src-3559fc424d5cbd299bdc02973b8e6b3c87a406ab.zip
chromium_src-3559fc424d5cbd299bdc02973b8e6b3c87a406ab.tar.gz
chromium_src-3559fc424d5cbd299bdc02973b8e6b3c87a406ab.tar.bz2
Assume the foo_test_run depends on everything needed to run the test.
It previously assumed foo_test was the target to process. This doesn't work in cases where there is no foo_test target defined. R=kbr@chromium.org BUG=368543 Review URL: https://codereview.chromium.org/266923004 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@268409 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'tools/isolate_driver.py')
-rwxr-xr-xtools/isolate_driver.py9
1 files changed, 7 insertions, 2 deletions
diff --git a/tools/isolate_driver.py b/tools/isolate_driver.py
index a779820..4db823e 100755
--- a/tools/isolate_driver.py
+++ b/tools/isolate_driver.py
@@ -13,6 +13,10 @@ be used so the wrapping .isolate doesn't affect this value.
This script loads build.ninja and processes it to determine all the executables
referenced by the isolated target. It adds them in the wrapping .isolate file.
+
+WARNING: The target to use for build.ninja analysis is the base name of the
+.isolate file plus '_run'. For example, 'foo_test.isolate' would have the target
+'foo_test_run' analysed.
"""
import StringIO
@@ -211,8 +215,9 @@ def create_wrapper(args, isolate_index, isolated_index):
'.', temp_isolate_dir).replace(os.path.sep, '/')
# It's a big assumption here that the name of the isolate file matches the
- # primary target. Fix accordingly if this doesn't hold true.
- target = isolate[:-len('.isolate')]
+ # primary target '_run'. Fix accordingly if this doesn't hold true, e.g.
+ # complain to maruel@.
+ target = isolate[:-len('.isolate')] + '_run'
build_steps = load_ninja(build_dir)
binary_deps = post_process_deps(build_dir, recurse(target, build_steps, None))
logging.debug(